#!/bin/sh

# Copyright (C) 2019, 2020 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# The hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with the GNU Hurd.  If not, see <http://www.gnu.org/licenses/>.

. ./package-versions.sh
. ./environment-variables.sh

echo ""
echo "File: download-funcs.sh"

download () {
   if [ -f $1 ]; then
      return 0
   fi
   print_info "downloading $2"
   wget $2
}

unpack () {
   if [ -d "$3" ]; then
      return 0
   fi
   print_info "unpacking $2"
   tar $1 $2
}

download_binutils () {
   download $BINUTILS_PKG $BINUTILS_URL
   if [ -d "$BINUTILS_SRC" ]; then
      return 0
   fi
   unpack jxf $BINUTILS_PKG $BINUTILS_SRC
 }

# git clone
download_gnumach () {
   if [ -d "$GNUMACH_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.gnu.org/git/hurd/gnumach.git
   #FIXME: Move to bootstrap.sh, compile.sh: apply+unapply
   cd $GNUMACH_SRC
   apply_patch $SCRIPT_DIR/patches/gnumach/gnumach_Makefile.am.diff 1
   cd ..
}

# git clone
download_mig () {
   if [ -d "$MIG_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.gnu.org/git/hurd/mig.git
}

#FIXME: lwip requires cmake!!
# git clone
download_lwip () {
   if [ -d "$LWIP_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.nongnu.org/git/lwip.git
}

# git clone
download_hurd () {
   if [ -d "$HURD_SRC" ]; then
      return 0
   fi
#   git clone https://git.savannah.gnu.org/git/hurd/hurd.git
   git clone git://git.savannah.gnu.org/hurd/hurd.git
}

download_gmp () {
   download $GMP_PKG $GMP_URL
   if [ -d "$GMP_SRC" ]; then
       return 0
   fi
   unpack jxf $GMP_PKG $GMP_SRC
}

download_mpfr () {
   download $MPFR_PKG $MPFR_URL
   if [ -d "$MPFR_SRC" ]; then
       return 0
   fi
   unpack Jxf $MPFR_PKG $MPFR_SRC
}

download_mpc () {
   download $MPC_PKG $MPC_URL
   if [ -d "$MPC_SRC" ]; then
       return 0
   fi
   unpack zxf $MPC_PKG $MPC_SRC
}

download_e2fsprogs () {
   download $E2FSPROGS_PKG $E2FSPROGS_URL
   if [ -d "$E2FSPROGS_SRC" ]; then
       return 0
   fi
   unpack zxf $E2FSPROGS_PKG $E2FSPROGS_SRC
   cd $E2FSPROGS_SRC
   apply_patch $SCRIPT_DIR/patches/e2fsprogs/configure.ac.diff 1
   apply_patch $SCRIPT_DIR/patches/e2fsprogs/lib_ext2fs_dirhash.c.diff 1
   cd ..
}

download_libgpg-error () {
   download $LIBGPG_ERROR_PKG $LIBGPG_ERROR_URL
   if [ -d "$LIBGPG_ERROR_SRC" ]; then
      return 0
   fi
   unpack jxf $LIBGPG_ERROR_PKG $LIBGPG_ERROR_SRC
   cd $LIBGPG_ERROR_SRC
   apply_patch $SCRIPT_DIR/patches/libgpg-error/libgpg-error-gawk-5.0.diff 1
   cd ..
}

download_libgcrypt20 () {
   download $LIBGCRYPT20_PKG $LIBGCRYPT20_URL
   if [ -d "$LIBGCRYPT20_SRC" ]; then
      return 0
   fi
   unpack jxf $LIBGCRYPT20_PKG $LIBGCRYPT20_SRC
}

download_libpciaccess () {
   download $LIBPCIACCESS_PKG $LIBPCIACCESS_URL
   if [ -d "$LIBPCIACCESS_SRC" ]; then
       return 0
   fi
   unpack zxf $LIBPCIACCESS_PKG $LIBPCIACCESS_SRC
}

download_pkg-config () {
   download $PKG_CONFIG_PKG $PKG_CONFIG_URL
   if [ -d "$PKG_CONFIG_SRC" ]; then
       return 0
   fi
   unpack zxf $PKG_CONFIG_PKG $PKG_CONFIG_SRC
   cd $PKG_CONFIG_SRC
   apply_patch $SCRIPT_DIR/patches/pkg-config/glib-gettest.m4.diff 1
   cd ..
}
   
download_util-linux () {
   download $UTIL_LINUX_PKG $UTIL_LINUX_URL
   if [ -d "$UTIL_LINUX_SRC" ]; then
       return 0
   fi
   unpack zxf $UTIL_LINUX_PKG $UTIL_LINUX_SRC
}
   
# Don't run mkfixinc.sh ->
#   unapply_patch $SCRIPT_DIR/patches/gcc/mkfixinc.sh.diff 1
#   apply_patch $SCRIPT_DIR/patches/gcc/mkfixinc.sh.diff 1
download_gcc () {
   download $GCC_PKG $GCC_URL
   if [ -d "$GCC_SRC" ]; then
      return 0
   fi
   unpack zxf $GCC_PKG $GCC_SRC
   cd $GCC_SRC
   apply_patch $SCRIPT_DIR/patches/gcc/gcc-Makefile.in.diff 1
   apply_patch $SCRIPT_DIR/patches/gcc/specs.patch 1
   apply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
   cd .. 
}

download_glibc () {
   download $GLIBC_PKG $GLIBC_URL
   if [ -d "$GLIBC_SRC" ]; then
      return 0
   fi
   unpack zxf $GLIBC_PKG $GLIBC_SRC
   cd $GLIBC_SRC
   apply_patch $SCRIPT_DIR/patches/glibc/Makefile.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/git-ONSTACK.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-mach-hurd-link.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-hurdsig-fixes.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-hurdsig-global-dispositions.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-hurdsig-SA_SIGINFO.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-hurdsig-fixes-2.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-sigstate_thread_reference.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/glibc.git-0b262ca4c64cd9042576ddb9969607c0ea1187d7.patch 1
   cd ..
}

download_zlib () {
   download $ZLIB_PKG $ZLIB_URL
   if [ -d "$ZLIB_SRC" ]; then
      return 0
   fi
   unpack zxf $ZLIB_PKG $ZLIB_SRC
}

download_flex () {
   download $FLEX_PKG $FLEX_URL
   if [ -d "$FLEX_SRC" ]; then
      return 0
   fi
   unpack zxf $FLEX_PKG $FLEX_SRC
}

download_coreutils () {
    download $COREUTILS_PKG $COREUTILS_URL
    if [ ! -d "$COREUTILS_SRC" ]; then
	unpack Jxf $COREUTILS_PKG $COREUTILS_SRC
	cd $COREUTILS_SRC
	# apply_patch $SCRIPT_DIR/patches/coreutils/*.patch 1
	cd ..
    fi
}

download_bash() {
   download $BASH_PKG $BASH_URL
   if [ -d "$BASH_SRC" ]; then
      return 0
   fi
   unpack zxf $BASH_PKG $BASH_SRC
}

download_sed () {
    download $SED_PKG $SED_URL
    if [ -d "$SED_SRC" ]; then
	return 0
    fi
    unpack xf $SED_PKG $SED_SRC
}

download_ncurses () {
  download $NCURSES_PKG $NCURSES_URL
  if [ -d "$NCURSES_SRC" ]; then
    return 0
  fi
  unpack zxf $NCURSES_PKG $NCURSES_SRC
}

download_pam () {
    download $PAM_PKG $PAM_URL
    if [ -d "$PAM_SRC" ]; then
	return 0
    fi
    unpack Jxf $PAM_PKG $PAM_SRC
    cd $PAM_SRC
    apply_patch $SCRIPT_DIR/patches/Linux-PAM/hurd_no_setfsuid.diff 1
    apply_patch $SCRIPT_DIR/patches/Linux-PAM/fix-autoreconf.patch 1
    cd ..
}

download_shadow () {
    download $SHADOW_PKG $SHADOW_URL
    if [ -d "$SHADOW_SRC" ]; then
	return 0
    fi
    unpack Jxf $SHADOW_PKG $SHADOW_SRC
    cd $SHADOW_SRC
    apply_patch $SCRIPT_DIR/patches/shadow/non-linux.diff 1
    cd ..
}

download_grub () {
    download $GRUB_PKG $GRUB_URL
    if [ -d "$GRUB_SRC" ]; then
	return 0
    fi
    unpack zxf $GRUB_PKG $GRUB_SRC
    cd $GRUB_SRC
    apply_patch $SCRIPT_DIR/patches/grub/grub-core_osdep_generic_blocklist.c.patch 1
    cd ..
}

download_nano () {
  download $NANO_PKG $NANO_URL
  if [ -d "$NANO_SRC" ]; then
    return 0
  fi
  unpack Jxf $NANO_PKG $NANO_SRC
}

download_vim () {
  download $VIM_PKG $VIM_URL
  if [ -d "vim$VIM_BASE_VERSION" ]; then
    return 0
  fi
  unpack jxf $VIM_PKG $VIM_SRC
}

