#!/bin/sh

# Copyright (C) 2019, 2020 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# The hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with the GNU Hurd.  If not, see <http://www.gnu.org/licenses/>.

. ./download-funcs.sh

echo ""
echo "File: download.sh"

print_info "*************************************"
print_info "Downloading and patching source files"
print_info "*************************************"

cd $SRC

if [ ! -f $STAMPS_DOWNLOAD/$BINUTILS_SRC ]; then
    print_info "Downloading binutils"
    download_binutils
    touch $STAMPS_DOWNLOAD/$BINUTILS_SRC
fi
if [ ! -f $STAMPS_DOWNLOAD/$GNUMACH_SRC-git ]; then
    print_info "git clone gnumach"
    download_gnumach
    touch $STAMPS_DOWNLOAD/$GNUMACH_SRC-git
fi

if [ ! -f $STAMPS_DOWNLOAD/$GNUMIG_SRC-git ]; then
    print_info "git clone mig"
    download_mig
    touch $STAMPS_DOWNLOAD/$GNUMIG_SRC-git
fi

if [ ! -f $STAMPS_DOWNLOAD/$HURD_SRC-git ]; then
    print_info "git clone hurd"
    download_hurd
    touch $STAMPS_DOWNLOAD/$HURD_SRC-git
fi

if [ ! -f $STAMPS_DOWNLOAD/$GMP_SRC ]; then
    print_info "Downloading gmp"
    download_gmp
    touch $STAMPS_DOWNLOAD/$GMP_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$MPFR_SRC ]; then
    print_info "Downloading mpfr"
    download_mpfr
    touch $STAMPS_DOWNLOAD/$MPFR_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$MPC_SRC ]; then
    print_info "Downloading mpc"
    download_mpc
    touch $STAMPS_DOWNLOAD/$MPC_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$E2FSPROGS_SRC ]; then
    print_info "Downloading e2fsprogs"
    download_e2fsprogs
    touch $STAMPS_DOWNLOAD/$E2FSPROGS_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$LIBGPG_ERROR_SRC ]; then
    print_info "Downloading libgpg-error"
    download_libgpg-error
    touch $STAMPS_DOWNLOAD/$LIBGPG_ERROR_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$LIBGCRYPT20_SRC ]; then
    print_info "Downloading libgcrypt20"
    download_libgcrypt20
    touch $STAMPS_DOWNLOAD/$LIBGCRYPT20_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$LIBPCIACCESS_SRC ]; then
    print_info "Downloading libpciaccess"
    download_libpciaccess
    touch $STAMPS_DOWNLOAD/$LIBPCIACCESS_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$PKG_CONFIG_SRC ]; then
    print_info "Downloading pkg-config"
    download_pkg-config
    touch $STAMPS_DOWNLOAD/$PKG_CONFIG_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$UTIL_LINUX_SRC ]; then
    print_info "Downloading util-linux"
    download_util-linux
    touch $STAMPS_DOWNLOAD/$UTIL_LINUX_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$GCC_SRC ]; then
    print_info "Downloading gcc"
    download_gcc
    touch $STAMPS_DOWNLOAD/$GCC_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$GLIBC_SRC ]; then
    print_info "Downloading glibc"
    download_glibc
    touch $STAMPS_DOWNLOAD/$GLIBC_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$ZLIB_SRC ]; then
    print_info "Downloading zlib"
    download_zlib
    touch $STAMPS_DOWNLOAD/$ZLIB_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$FLEX_SRC ]; then
    print_info "Downloading flex"
    download_flex
    touch $STAMPS_DOWNLOAD/$FLEX_SRC
fi

#if [ ! -f $DOWNLOAD/lwip-stamp ]; then
#    print_info "git clone lwip: Cannot be built, requires CMAKE"
#    download_lwip
#    touch $DOWNLOAD/lwip-stamp
#fi

if [ ! -f $STAMPS_DOWNLOAD/$COREUTILS_SRC ]; then
    print_info "Downloading coreutils"
    download_coreutils
    touch $STAMPS_DOWNLOAD/$COREUTILS_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$BASH_SRC ]; then
    print_info "Downloading bash"
    download_bash
    touch $STAMPS_DOWNLOAD/$BASH_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$SED_SRC ]; then
    print_info "Downloading sed"
    download_sed
    touch $STAMPS_DOWNLOAD/$SED_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$NCURSES_SRC ]; then
    print_info "Downloading ncurses"
    download_ncurses
    touch $STAMPS_DOWNLOAD/$NCURSES_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$PAM_SRC ]; then
    print_info "Downloading pam"
    download_pam
    touch $STAMPS_DOWNLOAD/$PAM_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$SHADOW_SRC ]; then
    print_info "Downloading shadow"
    download_shadow
    touch $STAMPS_DOWNLOAD/$SHADOW_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$GRUB_SRC ]; then
    print_info "Downloading grub"
    download_grub
    touch $STAMPS_DOWNLOAD/$GRUB_SRC
fi

if [ ! -f $STAMPS_DOWNLOAD/$NANO_SRC ]; then
    print_info "Downloading nano"
    download_nano
    touch $STAMPS_DOWNLOAD/$NANO_SRC
fi

#FIXME later
#download_vim

print_info "**********************************"
print_info "Downloading and Patching completed"
print_info "**********************************"

exit 0
