#!/bin/sh

# Copyright (C) 2019, 2020 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# The hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with the GNU Hurd.  If not, see <http://www.gnu.org/licenses/>.

echo ""
echo "File: package-versions.sh"

BINUTILS_VERSION=2.33.1
GCC_VERSION=9.2.0
GLIBC_VERSION=2.30
FLEX_VERSION=2.6.4
ZLIB_VERSION=1.2.11
BASH_VERSION=5.0
COREUTILS_VERSION=8.31
PKG_CONFIG_VERSION=0.29.2
LIBPCIACCESS_VERSION=0.16
UTIL_LINUX_VERSION1=2.35
UTIL_LINUX_VERSION=2.35-rc1
E2FSPROGS_VERSION=1.45.4
GRUB_VERSION=2.04
PAM_VERSION=1.3.1
SHADOW_VERSION=4.8
SED_VERSION=4.7
GMP_VERSION=6.1.2
MPFR_VERSION=4.0.2
MPC_VERSION=1.1.0
NCURSES_VERSION=6.1
LIBGCRYPT20_VERSION=1.8.5
LIBGPG_ERROR_VERSION=1.36
NANO_VERSION=4.6
VIM_BASE_VERSION=81
VIM_VERSION=8.1

# Mig, Mach, lwip and Hurd are all taken from the Git repository.

BINUTILS_SRC=binutils-"$BINUTILS_VERSION"
BINUTILS_PKG="${BINUTILS_SRC}.tar.bz2"
GCC_SRC=gcc-"$GCC_VERSION"
GCC_PKG="$GCC_SRC".tar.gz
GLIBC_SRC=glibc-"$GLIBC_VERSION"
GLIBC_PKG="$GLIBC_SRC".tar.gz
#FIXME: Rename next three to *-git
GNUMACH_SRC=gnumach
GNUMIG_SRC=mig
HURD_SRC=hurd
LWIP_SRC=lwip
LIBGCRYPT20_SRC=libgcrypt-"$LIBGCRYPT20_VERSION"
LIBGCRYPT20_PKG="${LIBGCRYPT20_SRC}.tar.bz2"
LIBGPG_ERROR_SRC=libgpg-error-"$LIBGPG_ERROR_VERSION"
LIBGPG_ERROR_PKG="${LIBGPG_ERROR_SRC}.tar.bz2"
FLEX_SRC=flex-"$FLEX_VERSION"
FLEX_PKG="$FLEX_SRC".tar.gz
ZLIB_SRC=zlib-"$ZLIB_VERSION"
ZLIB_PKG="$ZLIB_SRC".tar.gz
BASH_SRC=bash-"$BASH_VERSION"
BASH_PKG="$BASH_SRC".tar.gz
COREUTILS_SRC=coreutils-"$COREUTILS_VERSION"
COREUTILS_PKG="$COREUTILS_SRC".tar.xz
E2FSPROGS_SRC=e2fsprogs-"$E2FSPROGS_VERSION"
E2FSPROGS_PKG="$E2FSPROGS_SRC".tar.gz
PKG_CONFIG_SRC=pkg-config-"$PKG_CONFIG_VERSION"
PKG_CONFIG_PKG="$PKG_CONFIG_SRC".tar.gz
LIBPCIACCESS_SRC=libpciaccess-"$LIBPCIACCESS_VERSION"
LIBPCIACCESS_PKG="$LIBPCIACCESS_SRC".tar.gz
UTIL_LINUX_SRC=util-linux-"$UTIL_LINUX_VERSION"
UTIL_LINUX_PKG="$UTIL_LINUX_SRC".tar.gz
GRUB_SRC=grub-"$GRUB_VERSION"
GRUB_PKG="$GRUB_SRC".tar.gz
PAM_SRC=Linux-PAM-"$PAM_VERSION"
PAM_PKG="$PAM_SRC".tar.xz
SHADOW_SRC=shadow-"$SHADOW_VERSION"
SHADOW_PKG="$SHADOW_SRC".tar.xz
SED_SRC=sed-"$SED_VERSION"
SED_PKG="$SED_SRC".tar.xz
GMP_SRC=gmp-"$GMP_VERSION"
GMP_PKG="${GMP_SRC}".tar.bz2
MPFR_SRC=mpfr-"$MPFR_VERSION"
MPFR_PKG="${MPFR_SRC}".tar.xz
MPC_SRC=mpc-"$MPC_VERSION"
MPC_PKG="${MPC_SRC}".tar.gz
NCURSES_SRC=ncurses-"$NCURSES_VERSION"
NCURSES_PKG="${NCURSES_SRC}".tar.gz
VIM_SRC=vim-"$VIM_VERSION"
VIM_PKG="$VIM_SRC".tar.bz2
NANO_SRC=nano-"$NANO_VERSION"
NANO_PKG="$NANO_SRC".tar.xz

BINUTILS_URL=https://ftp.gnu.org/gnu/binutils/$BINUTILS_PKG
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-"$GCC_VERSION"/"$GCC_PKG"
GLIBC_URL=https://ftp.gnu.org/gnu/glibc/"$GLIBC_PKG"
FLEX_URL=https://github.com/westes/flex/releases/download/v$FLEX_VERSION/$FLEX_PKG
ZLIB_URL=http://zlib.net/"$ZLIB_PKG"
PKG_CONFIG_URL=https://pkg-config.freedesktop.org/releases/"$PKG_CONFIG_PKG"
LIBPCIACCESS_URL=https://xorg.freedesktop.org/releases/individual/lib/"$LIBPCIACCESS_PKG"
BASH_URL=https://ftp.gnu.org/gnu/bash/"$BASH_PKG"
COREUTILS_URL=https://ftp.gnu.org/gnu/coreutils/"$COREUTILS_PKG"
E2FSPROGS_URL=https://www.kernel.org/pub/linux/kernel/people/tytso/e2fsprogs/v"$E2FSPROGS_VERSION"/"$E2FSPROGS_PKG"
UTIL_LINUX_URL=https://mirrors.edge.kernel.org/pub/linux/utils/util-linux/v"$UTIL_LINUX_VERSION1"/"$UTIL_LINUX_PKG"
GRUB_URL=https://ftp.gnu.org/gnu/grub/"$GRUB_PKG"
PAM_URL=https://github.com/linux-pam/linux-pam/releases/download/v"$PAM_VERSION"/"$PAM_PKG"
SHADOW_URL=https://github.com/shadow-maint/shadow/releases/download/"$SHADOW_VERSION"/"$SHADOW_PKG"
SED_URL=https://ftp.gnu.org/gnu/sed/"$SED_PKG"
GMP_URL=https://ftp.gnu.org/gnu/gmp/"$GMP_PKG"
MPFR_URL=http://ftp.gnu.org/gnu/mpfr/"$MPFR_PKG"
MPC_URL=https://ftp.gnu.org/gnu/mpc/"$MPC_PKG"
NCURSES_URL=https://ftp.gnu.org/gnu/ncurses/"$NCURSES_PKG"
LIBGCRYPT20_URL=https://gnupg.org/ftp/gcrypt/libgcrypt/"$LIBGCRYPT20_PKG"
LIBGPG_ERROR_URL=https://www.gnupg.org/ftp/gcrypt/libgpg-error/"$LIBGPG_ERROR_PKG"
NANO_URL=https://www.nano-editor.org/dist/v4/"$NANO_PKG"
VIM_URL=ftp://ftp.vim.org/pub/vim/unix/"$VIM_PKG"
